#!/bin/bash
#------------------------------------------------------------------------------
# /var/install/config.d/qemu-ga.sh
#
# Last Update: 2023-04-20 se, sebastian(dot)ertz(at)tk(minus)ertz(dot)de
#
# Copyright (c) 2001-2024 the eisfair team, team(at)eisfair(dot)org
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#------------------------------------------------------------------------------
#==============================================================================
# { Menu 2021-03-29
#==============================================================================
RmMenu(){
	/var/install/bin/del-menu "setup.services.menu" "setup.services.qemu-ga.menu"
	rm -f /var/install/menu/qemu-ga.*
}
Menu(){
	/var/install/bin/add-menu --menu "setup.services.menu" "setup.services.qemu-ga.menu" "QEMU Guest Agent Service"
}
#==============================================================================
# } Menu
#==============================================================================
#==============================================================================
# { Service 2023-04-11
#==============================================================================
ServiceDaemonReload(){
	/usr/sbin/service daemon-reload
}
ServiceStart(){
	/usr/sbin/service restart "${1:-qemu-ga.service}" 2>/dev/null
}
ServiceStartIfEnabled(){
	ServiceIsEnabled "${1:-qemu-ga.service}" && ServiceStart "${1:-qemu-ga.service}"
}
ServiceStop(){
	/usr/bin/systemctl --quiet is-active "${1:-qemu-ga.service}" && /usr/sbin/service stop "${1:-qemu-ga.service}"
}
ServiceStopQuiet(){
	/usr/bin/systemctl --quiet is-active "${1:-qemu-ga.service}" && /usr/sbin/service --quiet stop "${1:-qemu-ga.service}" >/dev/null 2>/dev/null
}
ServiceEnable(){
	/usr/sbin/service enable "${1:-qemu-ga.service}"
}
ServiceDisable(){
	/usr/sbin/service disable "${1:-qemu-ga.service}"
}
ServiceIsEnabled(){
	/usr/sbin/service --quiet is-enabled "${1:-qemu-ga.service}"
}
#==============================================================================
# } Service
#==============================================================================

#==============================================================================
# Config
#==============================================================================
Config(){
	ServiceEnable qemu-ga.service
}

#==============================================================================
# Install
#==============================================================================
Install(){
	ServiceDaemonReload
	ServiceStopQuiet qemu-ga.service
	Config
	Menu
	# 3.2.6 -> 3.2.7
	rm -f \
		/etc/backup.d/qemu-ga.* \
		/etc/config.d/qemu-ga \
		/etc/default.d/qemu-ga \
		/var/install/menu/qemu-ga.*
	ServiceStart qemu-ga.service
}

#==============================================================================
# Update
#==============================================================================
Update(){
	ServiceDisable qemu-ga.service
	ServiceStop qemu-ga.service
}

#==============================================================================
# Uninstall
#==============================================================================
Uninstall(){
	Update
	RmMenu
}

#==============================================================================
# Main
#==============================================================================
Main(){
	case "${1,,}" in
		install  ) Install  ;;
		update   ) Update   ;;
		uninstall) Uninstall;;
		*        ) Config   ;;
	esac
}
Main "$@"

#==============================================================================
# End
#==============================================================================
exit 0
